package com.ruoyi.system.controller;

import java.util.List;
import java.io.IOException;
import javax.servlet.http.HttpServletResponse;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.log.annotation.Log;
import com.ruoyi.common.log.enums.BusinessType;
import com.ruoyi.common.security.annotation.RequiresPermissions;
import com.ruoyi.system.domain.RmRegistrationMachine;
import com.ruoyi.system.service.IRmRegistrationMachineService;
import com.ruoyi.common.core.web.controller.BaseController;
import com.ruoyi.common.core.web.domain.AjaxResult;
import com.ruoyi.common.core.utils.poi.ExcelUtil;
import com.ruoyi.common.core.web.page.TableDataInfo;

/**
 * 绑定金山machinecodeController
 * 
 * @author gyt
 * @date 2025-10-10
 */
@RestController
@RequestMapping("/machine")
public class RmRegistrationMachineController extends BaseController
{
    @Autowired
    private IRmRegistrationMachineService rmRegistrationMachineService;

    /**
     * 查询绑定金山machinecode列表
     */
    @RequiresPermissions("system:machine:list")
    @GetMapping("/list")
    public TableDataInfo list(RmRegistrationMachine rmRegistrationMachine)
    {
        startPage();
        List<RmRegistrationMachine> list = rmRegistrationMachineService.selectRmRegistrationMachineList(rmRegistrationMachine);
        return getDataTable(list);
    }

    /**
     * 导出绑定金山machinecode列表
     */
    @RequiresPermissions("system:machine:export")
    @Log(title = "绑定金山machinecode", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, RmRegistrationMachine rmRegistrationMachine)
    {
        List<RmRegistrationMachine> list = rmRegistrationMachineService.selectRmRegistrationMachineList(rmRegistrationMachine);
        ExcelUtil<RmRegistrationMachine> util = new ExcelUtil<RmRegistrationMachine>(RmRegistrationMachine.class);
        util.exportExcel(response, list, "绑定金山machinecode数据");
    }

    /**
     * 获取绑定金山machinecode详细信息
     */
    @RequiresPermissions("system:machine:query")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(rmRegistrationMachineService.selectRmRegistrationMachineById(id));
    }

    /**
     * 新增绑定金山machinecode
     */
    @RequiresPermissions("system:machine:add")
    @Log(title = "绑定金山machinecode", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody RmRegistrationMachine rmRegistrationMachine)
    {
        return toAjax(rmRegistrationMachineService.insertRmRegistrationMachine(rmRegistrationMachine));
    }

    /**
     * 修改绑定金山machinecode
     */
    @RequiresPermissions("system:machine:edit")
    @Log(title = "绑定金山machinecode", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody RmRegistrationMachine rmRegistrationMachine)
    {
        return toAjax(rmRegistrationMachineService.updateRmRegistrationMachine(rmRegistrationMachine));
    }

    /**
     * 删除绑定金山machinecode
     */
    @RequiresPermissions("system:machine:remove")
    @Log(title = "绑定金山machinecode", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(rmRegistrationMachineService.deleteRmRegistrationMachineByIds(ids));
    }
}
